diff --git js/ajax.js js/ajax.js
index 00bcdd7..de28e76 100644
--- js/ajax.js
+++ js/ajax.js
@@ -82,8 +82,9 @@ Drupal.Views.Ajax.ajaxResponse = function(data) {
   else if (!data.tab) {
     // If no display, reset the form.
     Drupal.Views.Ajax.setForm('', Drupal.settings.views.ajax.defaultForm);
     //Enable the save button.
     $('#edit-save').removeAttr('disabled');
+    $('#edit-delete').removeAttr('disabled');
     // Trigger an update for the live preview when we reach this state:
     if ($('#views-ui-preview-form input#edit-live-preview').is(':checked')) {
       $('#views-ui-preview-form').trigger('submit');
@@ -260,8 +261,9 @@ Drupal.behaviors.ViewsAjaxLinks = function() {
     // Turn on the hilite to indicate this is in use.
     $(this).addClass('hilite');
 
     // Disable the save button.
     $('#edit-save').attr('disabled', 'true');
+    $('#edit-delete').attr('disabled', 'true');
 
     $(this).addClass('views-throbbing');
     $.ajax({
@@ -82,8 +82,9 @@ Drupal.Views.Ajax.ajaxResponse = function(data) {
     // If no display, reset the form.
     Drupal.Views.Ajax.setForm('', Drupal.settings.views.ajax.defaultForm);
-    //Enable the save button.
+    //Enable the save and delete button.
     $('#edit-save').removeAttr('disabled');
@@ -260,8 +261,9 @@ Drupal.behaviors.ViewsAjaxLinks = function() {
     $(this).addClass('hilite');
 
-    // Disable the save button.
+    // Disable the save and delete button.
     $('#edit-save').attr('disabled', 'true');
